Mpsqd is a python package that used matrix product states (MPS) to solve both the time dependent Schroding equation (TDSE) and the HEOM.

### Installation
pip install mpsqd

### Usage
Two modes of using the code are provided. 
- The first one is provided in the /examples, where the user provides necessary python files for initial conditions, construnction of the MPO, while use the package as a library to to the time depenent propagation
- The second approach uses the pre-built models, where the models are presented in the /models directory, examples for this type of usage in provided in the /ipynb diectory.

### Documentation
Primitive documentation can be found in the included .ipynb files

